==> nomachine-7.8.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/NXPingMonitor.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXPingMonitor;no warnings;(my $__pingTime=(0x1486+ 2581-0x1e9b));(my $__pongTime
=(0x124d+ 1092-0x1691));(my $__interval=(0x091c+ 2468-0x12c0));(my $__timeout=
(0x1f11+ 1686-0x25a7));(my $__errorTimeout=(0x00e6+ 316-0x0222));sub initialize{
__setTimeBetweenPings ();__setTimeoutForPingResponse ();__sendPing ();}sub 
__setTimeBetweenPings{($__interval=(0x2457+ 224-0x2519));Logger::debug (((
"\x4e\x58\x50\x69\x6e\x67\x4d\x6f\x6e\x69\x74\x6f\x72\x3a\x20\x54\x69\x6d\x65\x20\x62\x65\x74\x77\x65\x65\x6e\x20\x70\x69\x6e\x67\x73\x20\x74\x6f\x20\x74\x68\x65\x20\x73\x65\x72\x76\x65\x72\x3a\x20"
.$__interval)."\x2e"));}sub __setTimeoutForPingResponse{if ((not ((
$GLOBAL::NodeConnectionTimeout=~ /\d+/ )))){Logger::warning (
"\x4e\x58\x50\x69\x6e\x67\x4d\x6f\x6e\x69\x74\x6f\x72\x3a\x20\x49\x6e\x76\x61\x6c\x69\x64\x20\x76\x61\x6c\x75\x65\x20\x66\x6f\x72\x20\x74\x68\x65\x20\x4e\x6f\x64\x65\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x54\x69\x6d\x65\x6f\x75\x74\x20\x6b\x65\x79\x2e\x20\x55\x73\x69\x6e\x67\x20\x64\x65\x66\x61\x75\x6c\x74\x2e"
);($GLOBAL::NodeConnectionTimeout=(0x0688+ 151-0x06a7));}($__timeout=
$GLOBAL::NodeConnectionTimeout);Logger::debug (((
"\x4e\x58\x50\x69\x6e\x67\x4d\x6f\x6e\x69\x74\x6f\x72\x3a\x20\x54\x69\x6d\x65\x6f\x75\x74\x20\x66\x6f\x72\x20\x70\x69\x6e\x67\x20\x72\x65\x73\x70\x6f\x6e\x73\x65\x3a\x20"
.$__timeout)."\x2e"));}sub checkTimesAndSendPingIfNecessary{if ((__isPingEnabled
 ()==(0x032c+ 2193-0x0bbd))){return;}if ((__isTimeoutForPingRespose ()==
(0x07e7+ 6996-0x233a))){if ((__isErrorServerDidNotReply ()==
(0x1c78+ 1712-0x2327))){Logger::error (((
"\x53\x65\x72\x76\x65\x72\x20\x64\x69\x64\x20\x6e\x6f\x74\x20\x72\x65\x70\x6c\x79\x20\x73\x69\x6e\x63\x65\x20"
.$__timeout).
"\x20\x73\x65\x63\x6f\x6e\x64\x73\x2e\x20\x54\x65\x72\x6d\x69\x6e\x61\x74\x69\x6e\x67\x20\x73\x65\x73\x73\x69\x6f\x6e\x2e"
));NXSessionMonitor::__setSessionStatus ($NXSessionMonitor::statusError,((
"\x4c\x6f\x73\x74\x20\x63\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x74\x6f\x20\x4e\x58\x20\x73\x65\x72\x76\x65\x72\x3a\x20\x6e\x6f\x20\x72\x65\x70\x6c\x69\x65\x73\x20\x69\x6e\x20"
.$__timeout)."\x20\x73\x65\x63\x6f\x6e\x64\x73\x2e"));return;}
__setErrorServerDidNotReply ();Logger::warning (((
"\x53\x65\x72\x76\x65\x72\x20\x64\x69\x64\x20\x6e\x6f\x74\x20\x72\x65\x70\x6c\x79\x20\x73\x69\x6e\x63\x65\x20"
.$__timeout)."\x20\x73\x65\x63\x6f\x6e\x64\x73\x2e"));__sendPing ();return;}if (
(__isPingTime ()==(0x1774+ 3553-0x2554))){__sendPing ();return;}}sub handlePong{
Logger::debug (
"\x52\x65\x63\x65\x69\x76\x65\x64\x20\x70\x6f\x6e\x67\x20\x6d\x65\x73\x73\x61\x67\x65\x2e"
);__clearErrorServerDidNotReply ();__setPongTime ();__resetPingTime ();}sub 
handleRequestForPingMessage{Logger::debug (
"\x52\x65\x63\x65\x69\x76\x65\x64\x20\x72\x65\x71\x75\x65\x73\x74\x20\x66\x6f\x72\x20\x73\x65\x6e\x64\x20\x70\x69\x6e\x67\x20\x74\x6f\x20\x74\x68\x65\x20\x73\x65\x72\x76\x65\x72\x2e"
);__sendPing ();}sub __sendPing{Logger::debug (
"\x53\x65\x6e\x64\x69\x6e\x67\x20\x70\x69\x6e\x67\x20\x6d\x65\x73\x73\x61\x67\x65\x2e"
);(my $message=(((("\x4e\x58\x3e\x20".$GLOBAL::MSG_NODE_PING)."\x20").
$GLOBAL::MESSAGES_FORMAT{$GLOBAL::MSG_NODE_PING})."\x0a"));(my $bytes=
main::nxwrite (main::nxgetSTDOUT (),$message));if (($bytes==(-
(0x0fd0+ 4851-0x22c2)))){NXSessionMonitor::__setSessionStatus (
$NXSessionMonitor::statusError,
"\x4c\x6f\x73\x74\x20\x63\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x74\x6f\x20\x4e\x58\x20\x73\x65\x72\x76\x65\x72\x2e\x20\x43\x61\x6e\x6e\x6f\x74\x20\x73\x65\x6e\x64\x20\x70\x69\x6e\x67\x20\x6d\x65\x73\x73\x61\x67\x65\x20\x74\x6f\x20\x73\x65\x72\x76\x65\x72\x2e"
);return;}__resetPongTime ();__setPingTime ();}sub __isPingEnabled{if ((
$__timeout==(0x0174+ 7206-0x1d9a))){return ((0x0740+ 5642-0x1d4a));}return (
(0x0381+ 7166-0x1f7e));}sub __setPingTime{($__pingTime=
Common::NXTime::getSecondsSinceEpoch ());}sub __resetPingTime{($__pingTime=
(0x1e6c+ 230-0x1f52));}sub __isPingTime{if (($__pongTime==(0x08cc+ 3649-0x170d))
){return ((0x190f+ 429-0x1abc));}(my $time=Common::NXTime::getSecondsSinceEpoch 
());if (($time>=($__pongTime+$__interval))){return ((0x08c4+ 1602-0x0f05));}
return ((0x0a00+ 7288-0x2678));}sub __isTimeoutForPingRespose{if (($__pingTime==
(0x0ba9+ 1315-0x10cc))){return ((0x0efb+ 827-0x1236));}(my $time=
Common::NXTime::getSecondsSinceEpoch ());if (($__pingTime>$time)){($__pingTime=
Common::NXTime::getSecondsSinceEpoch ());}if (($time>=($__pingTime+$__timeout)))
{return ((0x1cfc+ 2430-0x2679));}return ((0x0339+ 6919-0x1e40));}sub 
__setErrorServerDidNotReply{($__errorTimeout=(0x0085+ 7989-0x1fb9));}sub 
__isErrorServerDidNotReply{return ($__errorTimeout);}sub 
__clearErrorServerDidNotReply{($__errorTimeout=(0x007b+ 1287-0x0582));}sub 
__setPongTime{($__pongTime=Common::NXTime::getSecondsSinceEpoch ());}sub 
__resetPongTime{($__pongTime=(0x19c9+ 705-0x1c8a));}return (
(0x04c9+ 7712-0x22e8));

==> nomachine-7.9.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/NXPingMonitor.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXPingMonitor;no warnings;(my $__pingTime=(0x066d+ 5067-0x1a38));(my $__pongTime
=(0x073d+ 2446-0x10cb));(my $__interval=(0x005b+ 9121-0x23fc));(my $__timeout=
(0x063d+ 4846-0x192b));(my $__errorTimeout=(0x1e9c+ 385-0x201d));sub initialize{
__setTimeBetweenPings ();__setTimeoutForPingResponse ();__sendPing ();}sub 
__setTimeBetweenPings{($__interval=(0x1323+ 3537-0x20d6));Logger::debug (((
"\x4e\x58\x50\x69\x6e\x67\x4d\x6f\x6e\x69\x74\x6f\x72\x3a\x20\x54\x69\x6d\x65\x20\x62\x65\x74\x77\x65\x65\x6e\x20\x70\x69\x6e\x67\x73\x20\x74\x6f\x20\x74\x68\x65\x20\x73\x65\x72\x76\x65\x72\x3a\x20"
.$__interval)."\x2e"));}sub __setTimeoutForPingResponse{if ((not ((
$GLOBAL::NodeConnectionTimeout=~ /\d+/ )))){Logger::warning (
"\x4e\x58\x50\x69\x6e\x67\x4d\x6f\x6e\x69\x74\x6f\x72\x3a\x20\x49\x6e\x76\x61\x6c\x69\x64\x20\x76\x61\x6c\x75\x65\x20\x66\x6f\x72\x20\x74\x68\x65\x20\x4e\x6f\x64\x65\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x54\x69\x6d\x65\x6f\x75\x74\x20\x6b\x65\x79\x2e\x20\x55\x73\x69\x6e\x67\x20\x64\x65\x66\x61\x75\x6c\x74\x2e"
);($GLOBAL::NodeConnectionTimeout=(0x03ff+ 199-0x044e));}($__timeout=
$GLOBAL::NodeConnectionTimeout);Logger::debug (((
"\x4e\x58\x50\x69\x6e\x67\x4d\x6f\x6e\x69\x74\x6f\x72\x3a\x20\x54\x69\x6d\x65\x6f\x75\x74\x20\x66\x6f\x72\x20\x70\x69\x6e\x67\x20\x72\x65\x73\x70\x6f\x6e\x73\x65\x3a\x20"
.$__timeout)."\x2e"));}sub checkTimesAndSendPingIfNecessary{if ((__isPingEnabled
 ()==(0x0d43+ 3761-0x1bf4))){return;}if ((__isTimeoutForPingRespose ()==
(0x056c+ 3861-0x1480))){if ((__isErrorServerDidNotReply ()==
(0x0f94+ 4281-0x204c))){Logger::error (((
"\x53\x65\x72\x76\x65\x72\x20\x64\x69\x64\x20\x6e\x6f\x74\x20\x72\x65\x70\x6c\x79\x20\x73\x69\x6e\x63\x65\x20"
.$__timeout).
"\x20\x73\x65\x63\x6f\x6e\x64\x73\x2e\x20\x54\x65\x72\x6d\x69\x6e\x61\x74\x69\x6e\x67\x20\x73\x65\x73\x73\x69\x6f\x6e\x2e"
));NXSessionMonitor::__setSessionStatus ($NXSessionMonitor::statusError,((
"\x4c\x6f\x73\x74\x20\x63\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x74\x6f\x20\x4e\x58\x20\x73\x65\x72\x76\x65\x72\x3a\x20\x6e\x6f\x20\x72\x65\x70\x6c\x69\x65\x73\x20\x69\x6e\x20"
.$__timeout)."\x20\x73\x65\x63\x6f\x6e\x64\x73\x2e"));return;}
__setErrorServerDidNotReply ();Logger::warning (((
"\x53\x65\x72\x76\x65\x72\x20\x64\x69\x64\x20\x6e\x6f\x74\x20\x72\x65\x70\x6c\x79\x20\x73\x69\x6e\x63\x65\x20"
.$__timeout)."\x20\x73\x65\x63\x6f\x6e\x64\x73\x2e"));__sendPing ();return;}if (
(__isPingTime ()==(0x15f3+ 3076-0x21f6))){__sendPing ();return;}}sub handlePong{
Logger::debug (
"\x52\x65\x63\x65\x69\x76\x65\x64\x20\x70\x6f\x6e\x67\x20\x6d\x65\x73\x73\x61\x67\x65\x2e"
);__clearErrorServerDidNotReply ();__setPongTime ();__resetPingTime ();}sub 
handleRequestForPingMessage{Logger::debug (
"\x52\x65\x63\x65\x69\x76\x65\x64\x20\x72\x65\x71\x75\x65\x73\x74\x20\x66\x6f\x72\x20\x73\x65\x6e\x64\x20\x70\x69\x6e\x67\x20\x74\x6f\x20\x74\x68\x65\x20\x73\x65\x72\x76\x65\x72\x2e"
);__sendPing ();}sub __sendPing{Logger::debug (
"\x53\x65\x6e\x64\x69\x6e\x67\x20\x70\x69\x6e\x67\x20\x6d\x65\x73\x73\x61\x67\x65\x2e"
);(my $message=(((("\x4e\x58\x3e\x20".$GLOBAL::MSG_NODE_PING)."\x20").
$GLOBAL::MESSAGES_FORMAT{$GLOBAL::MSG_NODE_PING})."\x0a"));(my $bytes=
main::nxwrite (main::nxgetSTDOUT (),$message));if (($bytes==(-
(0x0da3+ 3427-0x1b05)))){NXSessionMonitor::__setSessionStatus (
$NXSessionMonitor::statusError,
"\x4c\x6f\x73\x74\x20\x63\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x74\x6f\x20\x4e\x58\x20\x73\x65\x72\x76\x65\x72\x2e\x20\x43\x61\x6e\x6e\x6f\x74\x20\x73\x65\x6e\x64\x20\x70\x69\x6e\x67\x20\x6d\x65\x73\x73\x61\x67\x65\x20\x74\x6f\x20\x73\x65\x72\x76\x65\x72\x2e"
);return;}__resetPongTime ();__setPingTime ();}sub __isPingEnabled{if ((
$__timeout==(0x158a+ 432-0x173a))){return ((0x16bb+ 1940-0x1e4f));}return (
(0x0a97+ 6525-0x2413));}sub __setPingTime{($__pingTime=
Common::NXTime::getSecondsSinceEpoch ());}sub __resetPingTime{($__pingTime=
(0x23d8+ 627-0x264b));}sub __isPingTime{if (($__pongTime==(0x00b2+ 9583-0x2621))
){return ((0x0483+ 5492-0x19f7));}(my $time=Common::NXTime::getSecondsSinceEpoch
 ());if (($time>=($__pongTime+$__interval))){return ((0x06e7+ 7458-0x2408));}
return ((0x020c+ 2219-0x0ab7));}sub __isTimeoutForPingRespose{if (($__pingTime==
(0x02cb+ 1427-0x085e))){return ((0x1771+ 3252-0x2425));}(my $time=
Common::NXTime::getSecondsSinceEpoch ());if (($__pingTime>$time)){($__pingTime=
Common::NXTime::getSecondsSinceEpoch ());}if (($time>=($__pingTime+$__timeout)))
{return ((0x0635+ 3315-0x1327));}return ((0x0e1a+ 1134-0x1288));}sub 
__setErrorServerDidNotReply{($__errorTimeout=(0x040a+ 8240-0x2439));}sub 
__isErrorServerDidNotReply{return ($__errorTimeout);}sub 
__clearErrorServerDidNotReply{($__errorTimeout=(0x0d3d+ 2347-0x1668));}sub 
__setPongTime{($__pongTime=Common::NXTime::getSecondsSinceEpoch ());}sub 
__resetPongTime{($__pongTime=(0x168c+ 3738-0x2526));}return (
(0x12a2+ 1289-0x17aa));
